
.. _`Mapping between ValueMap and Values qualifiers`:

Mapping between ValueMap and Values qualifiers
----------------------------------------------

.. automodule:: pywbem._valuemapping

.. autoclass:: pywbem.ValueMapping
   :members:
